@@ -15,8 +15,8 @@
 #' @export
 maxae = function(truth, response, ...) {
   assert_regr(truth, response = response)
-  max(ae(truth, response))
+  max(.ae(truth, response))
 }
 
 #' @include measures.R
-add_measure(maxae, "Max Absolute Error", "regr", 0, Inf, TRUE)
+add_measure(maxae, "Max Absolute Error", "regr", 0, Inf, TRUE, obs_loss = "ae")
