@@ -15,8 +15,8 @@
 #' @export
 sse = function(truth, response, ...) {
   assert_regr(truth, response = response)
-  sum(se(truth, response))
+  sum(.se(truth, response))
 }
 
 #' @include measures.R
-add_measure(sse, "Sum of Squared Errors", "regr", 0, Inf, TRUE)
+add_measure(sse, "Sum of Squared Errors", "regr", 0, Inf, TRUE, obs_loss = "se")
