@@ -148,6 +148,7 @@ test_that("multiclass auc", {
   expect_equal(mauc_aunp(truth, prob), 1)
   expect_equal(mauc_au1u(truth, prob), 1)
   expect_equal(mauc_au1p(truth, prob), 1)
+  expect_equal(mauc_mu(truth, prob), 1)
 
   auc(truth = factor(c("a", "nota", "nota")), prob = c(1, 0, 0), positive = "a")
 
@@ -173,13 +174,14 @@ test_that("multiclass auc", {
   expect_equal(mauc_aunp(equalizer_truth, maxent_prob), 0.5)
   expect_equal(mauc_aunu(equalizer_truth, maxent_prob), 0.5)
   expect_equal(mauc_au1u(equalizer_truth, maxent_prob), 0.5)
+  expect_equal(mauc_mu(equalizer_truth, maxent_prob), 0.5)
 
   # reversing prob gives 1 - auc
   expect_equal(mauc_aunu(truth, prob), 1 - mauc_aunu(truth, 1 - prob))
   expect_equal(mauc_aunp(truth, prob), 1 - mauc_aunp(truth, 1 - prob))
   expect_equal(mauc_au1u(truth, prob), 1 - mauc_au1u(truth, 1 - prob))
   expect_equal(mauc_au1p(truth, prob), 1 - mauc_au1p(truth, 1 - prob))
-
+  expect_equal(mauc_mu(truth, prob), 1 - mauc_mu(truth, 1 - prob))
 
   # manually calculate au1u, au1p
   compmat = sapply(levels(truth), function(t1) {
@@ -201,5 +203,4 @@ test_that("multiclass auc", {
 
   expect_equal(mauc_aunu(truth, prob), mean(compvec))
   expect_equal(mauc_aunp(truth, prob), sum(compvec * table(truth) / length(truth)))
-
 })
